package doctor.controller;

import doctor.common.core.domain.HealthR;
import doctor.domain.dto.UserArchivesDto;
import doctor.domain.entity.*;
import doctor.domain.vo.*;
import doctor.service.UserVideoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

import static com.github.pagehelper.page.PageMethod.startPage;


/**
 * @ClassName : UserVideoController
 * @Description : 用户视频
 * @Author : FJJ
 * @Date: 2024-01-10 14:32
 */
@RestController
@RequestMapping("/user/verify/v1")
public class UserVideoController {
    @Autowired
        private UserVideoService userVideoService;

    //用户视频收藏列表
    @GetMapping("/findVideoCollectionList")
    public HealthR<List<UserVideoCollectionVo>> findVideoCollectionList(@RequestParam Integer page, @RequestParam Integer count,@RequestHeader Integer userId){
        startPage(page,count);
      List<UserVideoCollectionVo>  userVideoCollectionVos=userVideoService.findVideoCollectionList(userId);
        return HealthR.ok(userVideoCollectionVos);
    }
    //用户取消视频收藏
    @DeleteMapping("/cancelVideoCollection")
    public HealthR cancelVideoCollection(@RequestHeader Integer userId,@RequestHeader String sessionId,@RequestParam Integer videoId ){
        userVideoService.cancelVideoCollection(userId,sessionId,videoId);
        return HealthR.ok();
    }
    //用户购买视频列表
    @GetMapping("/findUserVideoBuyList")
    public HealthR<List<UserVideoBuyVo>>findUserVideoBuyList(@RequestParam Integer page, @RequestParam Integer count){
        startPage(page,count);
        List<UserVideoBuyVo> userVideoCollectionVos =userVideoService.findUserVideoBuyList();
        return HealthR.ok(userVideoCollectionVos);
    }
    //用户删除购买的视频
    @DeleteMapping("/deleteVideoBuy}")
    public HealthR deleteVideoBuy(@RequestParam Integer videoId){
        userVideoService.deleteVideoBuy(videoId);
        return HealthR.ok();
    }

    //我的钱包
    @GetMapping("/findUserWallet")
    public HealthR<List<UserWalletEntity>> findUserWallet(){
        List<UserWalletEntity> userWallets = userVideoService.findUserWallet();
        return HealthR.ok(userWallets);
    }
    //用户消费记录
    @GetMapping("/findUserConsumptionRecordList")
    public HealthR<List<UserConsumptionRecordVo>> findUserConsumptionRecordList(@RequestParam Integer page,@RequestParam Integer count){
        startPage(page,count);
        List<UserConsumptionRecordVo> userConsumptionRecordVos = userVideoService.findUserConsumptionRecordList();
        return HealthR.ok(userConsumptionRecordVos);
    }

    //用户详情页面
    @GetMapping("/whetherSignToday")
    public HealthR<List<UserEntity>> whetherSignToday(@RequestHeader Integer userId){
        List<UserEntity> userEntities = userVideoService.whetherSignToday(userId);
        return HealthR.ok(userEntities);
    }
   // 用户资讯收藏列表
    @GetMapping("/findUserInfoCollectionList")
    public HealthR<List<UserInfoCollectionVo>> findUserInfoCollectionList(){
        List<UserInfoCollectionVo> userInfoCollections = userVideoService.findUserInfoCollectionList();
        return HealthR.ok(userInfoCollections);
    }
    //用户被采纳意见列表
    @GetMapping("/findMyAdoptedCommentList")
    public HealthR<List<UserAdoptCommentVo>> findMyAdoptedCommentList(@RequestParam Integer page,@RequestParam Integer count){
        startPage(page,count);
        List<UserAdoptCommentVo> userAdoptCommentEntities = userVideoService.findMyAdoptedCommentList();
        return HealthR.ok(userAdoptCommentEntities);
    }
    //用户查看自己的档案
    @GetMapping("/findUserArchives")
    public HealthR<List<UserArchivesVo>> findUserArchives(@RequestHeader Integer userId){
        List<UserArchivesVo> userArchivesVos = userVideoService.findUserArchives(userId);
        return HealthR.ok(userArchivesVos);
    }
    //添加用户档案
    @PostMapping("/addUserArchives")
    public HealthR addUserArchives(@RequestBody  UserArchivesEntity userArchivesEntity, @RequestHeader Integer userId){
        userVideoService.addUserArchives(userArchivesEntity,userId);
        return HealthR.ok();
    }
    //上传用户档案图片
    @PostMapping("/uploadArchivesPicture")
    public HealthR uploadUserArchivesImg(@RequestParam Integer id){
        userVideoService.uploadUserArchivesImg(id);
        return HealthR.ok();
    }

    //用户关注医生列表

}
